@@ -34,10 +34,12 @@ class TestRegionEdgeCases(unittest.TestCase):
     )
 
     self.results = pd.read_csv(
-      path.join(self.load_data_path, 'results_concentric_regions.csv')
+      path.join(self.load_data_path, 'results_concentric_regions.csv'),
+      index_col=['measurement', 'region_id', 'timestamp']
     )
     self.results_ignore_sites = pd.read_csv(
-      path.join(self.load_data_path, 'results_concentric_regions_ignore_sites.csv')
+      path.join(self.load_data_path, 'results_concentric_regions_ignore_sites.csv'),
+      index_col=['measurement', 'region_id', 'timestamp']
     )
 
 
@@ -55,6 +57,7 @@ class TestRegionEdgeCases(unittest.TestCase):
 
     #print('Result: \n {}'.format(result))
     #print('Target: \n {}'.format(self.results))
+    #print('Compare: \n {}'.format(result.compare(self.results)))
 
     self.assertIsNotNone(estimator)
     self.assertIsNotNone(result)
@@ -76,23 +79,3 @@ class TestRegionEdgeCases(unittest.TestCase):
     self.assertIsNotNone(result)
     self.assertIsInstance(result, pd.DataFrame)
     self.assertTrue(result.equals(self.results_ignore_sites))
-
-  def test_high_max_processors(self):
-    """
-    Test that a ConcentricRegionsEstimator object can be initialized with region data containing regions that are all touching
-    and that the results are as expected
-    """
-    estimator = ConcentricRegionsEstimator(self.sites, self.regions, self.actuals,
-                                            verbose=0, max_processors=500)
-
-    self.assertIsNotNone(estimator.regions['neighbours'])
-    self.assertEqual(estimator.get_adjacent_regions(['SW']), ['CR', 'KT', 'SE', 'SM', 'TW', 'W', 'WC'])
-    result = estimator.get_estimations('NO2_mean', None, '2019-10-15')
-
-    #print('Result: \n {}'.format(result))
-    #print('Target: \n {}'.format(self.results))
-
-    self.assertIsNotNone(estimator)
-    self.assertIsNotNone(result)
-    self.assertIsInstance(result, pd.DataFrame)
-    self.assertTrue(result.equals(self.results))
