@@ -39,10 +39,12 @@ class TestRegionEdgeCases(unittest.TestCase):
     )
 
     self.results = pd.read_csv(
-      path.join(self.load_data_path, 'results_distance.csv')
+      path.join(self.load_data_path, 'results_distance.csv'),
+      index_col=['measurement', 'region_id', 'timestamp']
     )
     self.results_ignore_sites = pd.read_csv(
-      path.join(self.load_data_path, 'results_distance_ignore_sites.csv')
+      path.join(self.load_data_path, 'results_distance_ignore_sites.csv'),
+      index_col=['measurement', 'region_id', 'timestamp']
     )
 
   def test_ok_files(self):
@@ -75,20 +77,4 @@ class TestRegionEdgeCases(unittest.TestCase):
     self.assertIsNotNone(estimator)
     self.assertIsNotNone(result)
     self.assertIsInstance(result, pd.DataFrame)
-    self.assertTrue(result.equals(self.results_ignore_sites))
-
-  def test_high_max_processors(self):
-    """
-    Test that a DistanceEstimator object can be initialized with region data containing regions that are all touching
-    and that the results are as expected
-    """
-    estimator = DistanceSimpleEstimator(self.sites, self.regions, self.actuals, verbose=0, max_processors=500)
-    result = estimator.get_estimations('NO2_mean', None, '2019-10-15')
-
-    #print('Result: \n {}'.format(result))
-    #print('Target: \n {}'.format(self.results_touching))
-
-    self.assertIsNotNone(estimator)
-    self.assertIsNotNone(result)
-    self.assertIsInstance(result, pd.DataFrame)
-    self.assertTrue(result.equals(self.results))
\ No newline at end of file
+    self.assertTrue(result.equals(self.results_ignore_sites))
\ No newline at end of file
